
#	Skymeter, raadpleegt de Volumepagina van skynet selfcare,
#	verwerkt deze en bekomt de nuttige informatie.
#	
#	Copyright (C) 2003,2004,2005 Thomas Langewouters. 
#	
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#	
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

use strict;
my $debug = 0;	
my $silent = 0;
my $login;
my $password;
my $put_result;
my $webpage;
my $update_url =	"http://users.skynet.be/langewouters/skymeter_version.xml";
my $volumemeterurl = 	"https://e-care.skynet.be/index.cfm?function=connection.getVolume";
my $cookiefile = 	"/tmp/skymeter.cookie";
my $configfile =	"$ENV{HOME}/.skymeterrc";

sub curl_get_url
{
	my $url = shift; 
	my $command = "$CURLBIN -k -s -L -b $cookiefile -c $cookiefile $url";
	return `$command`;
}

sub curl_post_url
{
	my $url = shift; my $postdata = shift;
	my $command ="$CURLBIN -k -s -L -c $cookiefile -b $cookiefile -d \"$postdata\" $url";
	return `$command`;
}

sub check_for_update
{
	print "Controleren op update...\n";
	my $webpage = curl_get_url($update_url);

	if ($webpage =~ /<xml>/) 
	{
		$webpage =~ /<currentversion>(.*)<\/currentversion>/;
	    	my $newest = $1;
		
		$webpage =~ /<comment>(.*)<\/comment>/;
		my $comment = $1;

		print "Huidige versie: $VERSION, recentste: $newest\n";
		print "Opmerkingen: $comment\n";

	} 
	else
	{
		print "FOUT: update-pagina niet gevonden\n";
	}
}

sub usage
{
	print <<"EOF";
Usage: 
% skymeter [OPTION]

Options:
  --help        Print this message
  --version     Print version information
  -s, --silent  Geef handelingen niet weer
  --update      Kijk of er een nieuwere versie beschikbaar is
                (dit download geen tarball)
  --put         Steek de informatie in een file
  -u,--user     Gebruik deze username om in te loggen
  -p,--pass     Gebruik dit paswoord om in te loggen
                (bij gebruik van -p en -u word .skymeterrc niet gelezen)
		
Bug reports to: thomas.langewouters\@nospam.skynet.be
EOF
	exit(1);
}

sub version
{
 print <<"EOF";
Skymeter $VERSION 
EOF
 exit(1);
}

sub invalid
{
 print "Invalid usage. For help:\n";
 print "% $0 --help\n";
 exit(1);
}

# Verwerk commandoregel 
# #####################
my $n;
for($n = 0; $n <= $#ARGV; $n++)
{
	if ($ARGV[$n] eq "--version")
	{ version(); exit(0); 
	}
	elsif ($ARGV[$n] eq "--help")
	{ usage(); exit(0);
	}
	elsif ($ARGV[$n] eq "--update")
	{ check_for_update(); exit(0);
	}
	elsif ($ARGV[$n] eq "--put")
	{ $put_result = $ARGV[++$n]; 
	}
	elsif ($ARGV[$n] eq "-s" or $ARGV[$n] eq "--silent")
	{ $silent = 1; 
	}
	elsif ($ARGV[$n] eq "-p" or $ARGV[$n] eq "--pass")
	{ $password = $ARGV[++$n];
	}
	elsif ($ARGV[$n] eq "-u" or $ARGV[$n] eq "--user")
	{ $login = $ARGV[++$n]; 
	}
	else
	{ invalid(); }	
}

# Lees configuratiebestand
# ########################
if ($login eq "" or $password eq "")	# als er via commandline niets is opgegeven...
{
	open(INFILE, $configfile) or die "Can't open configuration file: $!";
	while (<INFILE>) 
	{	#assigns each line in turn to $_ 
		if ($_ =~ /^user (.*)/) { $login = $1; }
		if ($_ =~ /^pass (.*)/) { $password = $1}
	}
	close (INFILE);


	if (! $login || ! $password)
	{
		die "FOUT No username or password given\n";
	}
}

# Volumemeterpagina opvragen
# ##########################
if ($silent == 0)
{
	print "Aanvraag... ";
}
$webpage =  curl_get_url($volumemeterurl);

if ($debug) 
{
	open(OUTFILE, ">webpage1.html") or die "Can't open webpage1.html: $!";
	print OUTFILE $webpage; close (OUTFILE);
}

if (! ($webpage =~ /Basic monthly volume:/))	
{
	# Inloggen
	# #########
	if ($silent == 0)
	{
		print "Inloggen... ";
	}
	my $postdata="form_login=$login&form_password=$password&Langue_Id=2&fuseaction=CheckLoginConnection";
	$webpage = curl_post_url($volumemeterurl, $postdata);
	
	if ($debug) 
	{
		open(OUTFILE, ">webpage2.html") or die "Can't open webpage2.html: $!";
		print OUTFILE $webpage; close (OUTFILE);
	}
	
	if ( ! ($webpage =~ /Basic monthly volume:/))
	{
		# Authenticatie Mislukt!
		die ":-(\nFOUT: authenticatie mislukt !!!\nControleer uw username/paswoord.  Indien u zeker bent dat deze correct zijn, controleer dan op een nieuwe versie van skymeter met het commando\"skymeter --update\"\n";	
	}
}

# Cookiefile wissen
# ##################
print `rm $cookiefile`;

# Webpagina parsen
# #################
if ($silent == 0)
{
	print "Parsen... ";
}

#Monthly volume used <strong>    0.20 GB</strong> out of <strong>10 GB</strong>&nbsp;(9.8 GB remaining)</p>
$webpage =~/\s*(\d*\.*\d*)\s*GB<\/strong> out of <strong>(\d+)\s+GB/;
my $basis_used = $1;
my $basis_total = $2;

my $volumepack_used;
my $volumepack_total;
# FIXME slechts 1 reglex gebruiken hieronder, hierboven controleren of parsen gelukt is en exiten navenant
if ($webpage =~ /Volume Pack in current use: /) 
{
	#You used <strong>    2.78 GB</strong></font> out of &nbsp;<strong>5 GB</strong> available in the current Volume Pack (2.22 GB remaining)
	$webpage =~/You used <strong>\s*(\d*\.*\d*) GB<\/strong><\/font> out of &nbsp;<strong>(\d+) GB<\/strong> available in the current Volume Pack/;
	$volumepack_used = $1;
	$volumepack_total = $2;
}
else
{
	$volumepack_used = 0;
	$volumepack_total = 0;
}

# Parsen gelukt?
# ##############
if ($basis_total == "")
{
	print ":-(\nFOUT bij het verwerken van de pagina !!!\nDe structuur van de volumemeter webpagina is gewijzigd!!!\n";
	check_for_update();
	exit(1);
}
else
{
	if ($silent == 0)
	{
		print "Ok!\n";
	}
}

# Resultaten tonen op de gewenste manier
# ######################################

if ($put_result)
{
	# Plaats de informatie in een bestand.
	
	open(OUTFILE, ">$put_result") or die "Can't open $put_result: $!";
	print OUTFILE "Basisvolume: $basis_used / $basis_total\n";
	print OUTFILE "Volumepack: $volumepack_used / $volumepack_total\n";
	close (OUTFILE);
}
else
{
	# Toon informatie aan de gebruiker
	
	if (($basis_used / $basis_total) == 1) 
	{
		print "Volledig basisvollume gebruikt \n";
	} 
	else
	{
		print "Basisvolume [$basis_used / $basis_total] \n";
	}

	if ($volumepack_total > 0) 
	{
		print "Lopende volumepack: [$volumepack_used / $volumepack_total]\n";
	}
	else
	{
		print "U beschikt niet over een volumepack\n";
	}
}

exit(0);
